Class: Google::Developers::DeveloperKnowledge::V1::Answer
- Inherits:
-
Object
- Object
- Google::Developers::DeveloperKnowledge::V1::Answer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/developers/knowledge/v1/developerknowledge.rb
Overview
An answer to a query.
Defined Under Namespace
Classes: AnswerCitation, AnswerReference, CitationSource, DocumentReference
Instance Attribute Summary collapse
-
#answer_text ⇒ ::String
Contains the text of the answer.
-
#citations ⇒ ::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerCitation>
readonly
Output only.
-
#references ⇒ ::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerReference>
readonly
Output only.
Instance Attribute Details
#answer_text ⇒ ::String
Returns Contains the text of the answer.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 255 class Answer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Citation info for a segment. # @!attribute [r] start_index # @return [::Integer] # Output only. Indicates the start of the segment, measured in bytes (UTF-8 # unicode), inclusive. If there are multi-byte characters, such as # non-ASCII characters, the index measurement is longer than the string # length. # @!attribute [r] end_index # @return [::Integer] # Output only. Indicates the end of the segment, measured in bytes (UTF-8 # unicode), exclusive. If there are multi-byte characters, such as # non-ASCII characters, the index measurement is longer than the string # length. # @!attribute [r] sources # @return [::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::CitationSource>] # Output only. Contains citation sources for the attributed segment. class AnswerCitation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Citation source. # @!attribute [r] reference_index # @return [::Integer] # Output only. Contains the index of the # {::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerReference Answer.AnswerReference} # in the `references` repeated field. class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a reference to a source. # @!attribute [r] document_reference # @return [::Google::Developers::DeveloperKnowledge::V1::Answer::DocumentReference] # Output only. The reference document. class AnswerReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a reference to a document. # @!attribute [r] document_chunk # @return [::Google::Developers::DeveloperKnowledge::V1::DocumentChunk] # Output only. Contains the document chunk. The `document_chunk.id` field # is not set and will be empty. class DocumentReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#citations ⇒ ::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerCitation> (readonly)
Returns Output only. Contains citations for the answer.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 255 class Answer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Citation info for a segment. # @!attribute [r] start_index # @return [::Integer] # Output only. Indicates the start of the segment, measured in bytes (UTF-8 # unicode), inclusive. If there are multi-byte characters, such as # non-ASCII characters, the index measurement is longer than the string # length. # @!attribute [r] end_index # @return [::Integer] # Output only. Indicates the end of the segment, measured in bytes (UTF-8 # unicode), exclusive. If there are multi-byte characters, such as # non-ASCII characters, the index measurement is longer than the string # length. # @!attribute [r] sources # @return [::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::CitationSource>] # Output only. Contains citation sources for the attributed segment. class AnswerCitation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Citation source. # @!attribute [r] reference_index # @return [::Integer] # Output only. Contains the index of the # {::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerReference Answer.AnswerReference} # in the `references` repeated field. class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a reference to a source. # @!attribute [r] document_reference # @return [::Google::Developers::DeveloperKnowledge::V1::Answer::DocumentReference] # Output only. The reference document. class AnswerReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a reference to a document. # @!attribute [r] document_chunk # @return [::Google::Developers::DeveloperKnowledge::V1::DocumentChunk] # Output only. Contains the document chunk. The `document_chunk.id` field # is not set and will be empty. class DocumentReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#references ⇒ ::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerReference> (readonly)
Returns Output only. Contains references for the answer.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 255 class Answer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Citation info for a segment. # @!attribute [r] start_index # @return [::Integer] # Output only. Indicates the start of the segment, measured in bytes (UTF-8 # unicode), inclusive. If there are multi-byte characters, such as # non-ASCII characters, the index measurement is longer than the string # length. # @!attribute [r] end_index # @return [::Integer] # Output only. Indicates the end of the segment, measured in bytes (UTF-8 # unicode), exclusive. If there are multi-byte characters, such as # non-ASCII characters, the index measurement is longer than the string # length. # @!attribute [r] sources # @return [::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::CitationSource>] # Output only. Contains citation sources for the attributed segment. class AnswerCitation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Citation source. # @!attribute [r] reference_index # @return [::Integer] # Output only. Contains the index of the # {::Google::Developers::DeveloperKnowledge::V1::Answer::AnswerReference Answer.AnswerReference} # in the `references` repeated field. class CitationSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a reference to a source. # @!attribute [r] document_reference # @return [::Google::Developers::DeveloperKnowledge::V1::Answer::DocumentReference] # Output only. The reference document. class AnswerReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a reference to a document. # @!attribute [r] document_chunk # @return [::Google::Developers::DeveloperKnowledge::V1::DocumentChunk] # Output only. Contains the document chunk. The `document_chunk.id` field # is not set and will be empty. class DocumentReference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |