Class: Google::Developers::DeveloperKnowledge::V1::Answer::AnswerCitation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/developers/knowledge/v1/developerknowledge.rb

Overview

Citation info for a segment.

Instance Attribute Summary collapse

Instance Attribute Details

#end_index::Integer (readonly)

Returns Output only. Indicates the end of the segment, measured in bytes (UTF-8 unicode), exclusive. If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.

Returns:

  • (::Integer)

    Output only. Indicates the end of the segment, measured in bytes (UTF-8 unicode), exclusive. If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.



258
259
260
261
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 258

class AnswerCitation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sources::Array<::Google::Developers::DeveloperKnowledge::V1::Answer::CitationSource> (readonly)

Returns Output only. Contains citation sources for the attributed segment.

Returns:



258
259
260
261
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 258

class AnswerCitation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_index::Integer (readonly)

Returns Output only. Indicates the start of the segment, measured in bytes (UTF-8 unicode), inclusive. If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.

Returns:

  • (::Integer)

    Output only. Indicates the start of the segment, measured in bytes (UTF-8 unicode), inclusive. If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.



258
259
260
261
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 258

class AnswerCitation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end