Class: Google::Developers::DeveloperKnowledge::V1::SearchDocumentChunksResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/developers/knowledge/v1/developerknowledge.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns Optional. Provides a token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    Optional. Provides a token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



146
147
148
149
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 146

class SearchDocumentChunksResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#results::Array<::Google::Developers::DeveloperKnowledge::V1::DocumentChunk>

Returns Contains the search results for the given query. Each DocumentChunk in this list contains a snippet of content relevant to the search query. Use the DocumentChunk.parent field of each result with DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments to retrieve the full document content.

Returns:



146
147
148
149
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 146

class SearchDocumentChunksResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end