Class: Google::Developers::DeveloperKnowledge::V1::BatchGetDocumentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/developers/knowledge/v1/developerknowledge.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#names::Array<::String>

Returns Required. Specifies the names of the documents to retrieve. A maximum of 20 documents can be retrieved in a batch. The documents are returned in the same order as the names in the request.

Format: documents/{uri_without_scheme} Example: documents/docs.cloud.google.com/storage/docs/creating-buckets.

Returns:

  • (::Array<::String>)

    Required. Specifies the names of the documents to retrieve. A maximum of 20 documents can be retrieved in a batch. The documents are returned in the same order as the names in the request.

    Format: documents/{uri_without_scheme} Example: documents/docs.cloud.google.com/storage/docs/creating-buckets



187
188
189
190
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 187

class BatchGetDocumentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#view::Google::Developers::DeveloperKnowledge::V1::DocumentView

Returns Optional. Specifies the DocumentView of the document. If unspecified, DeveloperKnowledge.BatchGetDocuments defaults to DOCUMENT_VIEW_CONTENT.

Returns:



187
188
189
190
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 187

class BatchGetDocumentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end