Class: Google::Developers::DeveloperKnowledge::V1::Document

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/developers/knowledge/v1/developerknowledge.rb

Overview

A Document represents a piece of content from the Developer Knowledge corpus.

Instance Attribute Summary collapse

Instance Attribute Details

#content::String (readonly)

Returns Output only. Contains the full content of the document in Markdown format.

Returns:

  • (::String)

    Output only. Contains the full content of the document in Markdown format.



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_source::String (readonly)

Returns Output only. Specifies the data source of the document. Example data source: firebase.google.com.

Returns:

  • (::String)

    Output only. Specifies the data source of the document. Example data source: firebase.google.com



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String (readonly)

Returns Output only. Provides a description of the document.

Returns:

  • (::String)

    Output only. Provides a description of the document.



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. Contains the resource name of the document. Format: documents/{uri_without_scheme} Example: documents/docs.cloud.google.com/storage/docs/creating-buckets.

Returns:

  • (::String)

    Identifier. Contains the resource name of the document. Format: documents/{uri_without_scheme} Example: documents/docs.cloud.google.com/storage/docs/creating-buckets



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#title::String (readonly)

Returns Output only. Provides the title of the document.

Returns:

  • (::String)

    Output only. Provides the title of the document.



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Represents the timestamp when the content or metadata of the document was last updated.

Returns:



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String (readonly)

Returns Output only. Provides the URI of the content, such as docs.cloud.google.com/storage/docs/creating-buckets.

Returns:

  • (::String)

    Output only. Provides the URI of the content, such as docs.cloud.google.com/storage/docs/creating-buckets.



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#view::Google::Developers::DeveloperKnowledge::V1::DocumentView (readonly)

Returns Output only. Specifies the DocumentView of the document.

Returns:



56
57
58
59
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 56

class Document
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end