Class: Google::Developers::DeveloperKnowledge::V1::DocumentChunk
- Inherits:
-
Object
- Object
- Google::Developers::DeveloperKnowledge::V1::DocumentChunk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/developers/knowledge/v1/developerknowledge.rb
Overview
A DocumentChunk represents a piece of content from a
Document in the DeveloperKnowledge
corpus. To fetch the entire document content, pass the parent to
DeveloperKnowledge.GetDocument
or
DeveloperKnowledge.BatchGetDocuments.
Instance Attribute Summary collapse
-
#content ⇒ ::String
readonly
Output only.
-
#document ⇒ ::Google::Developers::DeveloperKnowledge::V1::Document
readonly
Output only.
-
#id ⇒ ::String
readonly
Output only.
-
#parent ⇒ ::String
readonly
Output only.
Instance Attribute Details
#content ⇒ ::String (readonly)
Returns Output only. Contains the content of the document chunk.
237 238 239 240 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 237 class DocumentChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#document ⇒ ::Google::Developers::DeveloperKnowledge::V1::Document (readonly)
Returns Output only. Represents metadata about the
Document this chunk is from. The
DocumentView of this
Document message will be set to
DOCUMENT_VIEW_BASIC. It is included here for convenience so that clients
do not need to call
DeveloperKnowledge.GetDocument
or
DeveloperKnowledge.BatchGetDocuments
if they only need the metadata fields. Otherwise, clients should use
DeveloperKnowledge.GetDocument
or
DeveloperKnowledge.BatchGetDocuments
to fetch the full document content.
237 238 239 240 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 237 class DocumentChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String (readonly)
Returns Output only. Specifies the ID of this chunk within the document. The chunk ID is unique within a document, but not globally unique across documents. The chunk ID is not stable and may change over time.
237 238 239 240 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 237 class DocumentChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String (readonly)
Returns Output only. Contains the resource name of the document this chunk is from.
Format: documents/{uri_without_scheme}
Example: documents/docs.cloud.google.com/storage/docs/creating-buckets.
237 238 239 240 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 237 class DocumentChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |