Class: Google::Developers::DeveloperKnowledge::V1::SearchDocumentChunksRequest
- Inherits:
-
Object
- Object
- Google::Developers::DeveloperKnowledge::V1::SearchDocumentChunksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/developers/knowledge/v1/developerknowledge.rb
Overview
Request message for DeveloperKnowledge.SearchDocumentChunks.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#query ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Applies a strict filter to the search results. The expression supports a subset of the syntax described at https://google.aip.dev/160.
While SearchDocumentChunks returns
DocumentChunks, the filter
is applied to DocumentChunk.document fields.
Supported fields for filtering:
data_source(STRING): The source of the document, e.g.docs.cloud.google.com. See https://developers.google.com/knowledge/reference/corpus-reference for the complete list of data sources in the corpus.update_time(TIMESTAMP): The timestamp of when the document was last meaningfully updated. A meaningful update is one that changes document's markdown content or metadata.uri(STRING): The document URI, e.g.https://docs.cloud.google.com/bigquery/docs/tables.
STRING fields support = (equals) and != (not equals) operators for
exact match on the whole string. Partial match, prefix match, and
regexp match are not supported.
TIMESTAMP fields support =, <, <=, >, and >= operators.
Timestamps must be in RFC-3339 format, e.g., "2025-01-01T00:00:00Z".
You can combine expressions using AND, OR, and NOT (or -) logical
operators. OR has higher precedence than AND. Use parentheses for
explicit precedence grouping.
Examples:
data_source = "docs.cloud.google.com" OR data_source = "firebase.google.com"data_source != "firebase.google.com"update_time < "2024-01-01T00:00:00Z"update_time >= "2025-01-22T00:00:00Z" AND (data_source = "developer.chrome.com" OR data_source = "web.dev")uri = "https://docs.cloud.google.com/release-notes"
The filter string must not exceed 500 characters; values longer than 500
characters will result in an INVALID_ARGUMENT error.
124 125 126 127 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 124 class SearchDocumentChunksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Specifies the maximum number of results to return. The service may return fewer than this value.
If unspecified, at most 5 results will be returned.
The maximum value is 20; values above 20 will result in an INVALID_ARGUMENT error.
124 125 126 127 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 124 class SearchDocumentChunksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Contains a page token, received from a previous
SearchDocumentChunks call. Provide this to retrieve the subsequent page.
124 125 126 127 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 124 class SearchDocumentChunksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::String
Returns Required. Provides the raw query string provided by the user, such as "How to create a Cloud Storage bucket?".
124 125 126 127 |
# File 'proto_docs/google/developers/knowledge/v1/developerknowledge.rb', line 124 class SearchDocumentChunksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |